@@ -15,7 +15,7 @@
 page_cursor <- function(client, req, limit = Inf) {
   qreq <- rlang::enquo(req)
 
-  prg <- progress::progress_bar$new(
+  prg <- optional_progress_bar(
     format = "downloading page :current (:tick_rate/sec) :elapsedfull",
     total = NA,
     clear = FALSE
@@ -58,7 +58,7 @@ page_offset <- function(client, req, limit = Inf) {
   qreq <- rlang::enquo(req)
   qexpr <- rlang::quo_get_expr(qreq)
 
-  prg <- progress::progress_bar$new(
+  prg <- optional_progress_bar(
     format = "downloading page :current (:tick_rate/sec) :elapsedfull",
     total = NA,
     clear = FALSE
@@ -95,3 +95,14 @@ page_offset <- function(client, req, limit = Inf) {
   }
   return(agg_response)
 }
+
+optional_progress_bar <- function(...) {
+  if (requireNamespace("progress", quietly = TRUE)) {
+    progress::progress_bar$new(...)
+  } else {
+    # Return a mock object that behaves enough like a progress bar object
+    list(
+      tick = function() {}
+    )
+  }
+}
